@@ -223,7 +223,7 @@ renv_available_packages_record <- function(entry, type) {
 renv_available_packages_latest_impl <- function(package, type) {
 
   dbs <- renv_available_packages(type = type, quiet = TRUE)
-  fields <- c("Package", "Version", "NeedsCompilation", "Repository")
+  fields <- c("Package", "Version", "OS_type", "NeedsCompilation", "Repository")
   entries <- bapply(dbs, function(db) {
 
     # extract entries for this package
@@ -235,6 +235,10 @@ renv_available_packages_latest_impl <- function(package, type) {
     deps <- rows$Depends %||% rep.int("", nrow(rows))
     compatible <- map_lgl(deps, function(dep) {
 
+      # skip NAs
+      if (is.na(dep))
+        return(TRUE)
+
       # read 'R' entries from Depends (if any)
       parsed <- catch(renv_description_parse_field(dep))
       if (inherits(parsed, "error")) {
@@ -295,7 +299,17 @@ renv_available_packages_latest <- function(package) {
 
   }
 
-  # get latest source, binary packages available
+  type <- getOption("pkgType")
+
+  # detect requests for only source packages
+  if (identical(type, "source"))
+    return(renv_available_packages_latest_impl(package, "source"))
+
+  # detect requests for only binary packages
+  if (grepl("\\bbinary\\b", type))
+    return(renv_available_packages_latest_impl(package, "binary"))
+
+  # otherwise, check both source and binary repositories
   src <- renv_available_packages_latest_impl(package, "source")
   bin <- renv_available_packages_latest_impl(package, "binary")
 
