@@ -25,9 +25,7 @@ diagnostics <- function(project = NULL) {
     renv_diagnostics_session,
     renv_diagnostics_project,
     renv_diagnostics_status,
-    renv_diagnostics_lockfile,
-    renv_diagnostics_library,
-    renv_diagnostics_dependencies,
+    renv_diagnostics_packages,
     renv_diagnostics_profile,
     renv_diagnostics_settings,
     renv_diagnostics_options,
@@ -42,7 +40,7 @@ diagnostics <- function(project = NULL) {
   vwritef(c(title, lines, ""))
 
   for (reporter in reporters) {
-    catch(reporter(project))
+    tryCatch(reporter(project), error = renv_error_handler)
     vwritef()
   }
 
@@ -64,58 +62,126 @@ renv_diagnostics_status <- function(project) {
   status(project = project)
 }
 
-renv_diagnostics_lockfile <- function(project) {
+renv_diagnostics_packages <- function(project) {
 
-  vwritef(header("Lockfile"))
+  vwritef(header("Packages"))
+
+  # collect state of lockfile, library, dependencies
+  lockfile <- renv_diagnostics_packages_lockfile(project)
+  libstate <- renv_diagnostics_packages_library(project)
+  used <- unique(renv_diagnostics_packages_dependencies(project)$Package)
+
+  # collect recursive package dependencies
+  recdeps <- renv_package_dependencies(
+    packages = used,
+    project  = project
+  )
+
+  # bundle together
+  all <- c(names(lockfile$Packages), names(libstate$Packages), names(recdeps))
+
+  # sort
+  renv_scope_locale(category = "LC_COLLATE", locale = "C")
+  all <- sort(unique(all))
+
+  # check which packages are direct, indirect requirements
+  deps <- rep.int(NA_character_, length(all))
+  names(deps) <- all
+  deps[names(recdeps)] <- "indirect"
+  deps[used] <- "direct"
+
+  # build libpaths for installed packages
+  libpaths <- dirname(map_chr(all, renv_package_find))
+
+  # use short form
+  flibpaths <- factor(libpaths, levels = .libPaths())
+
+  # construct integer codes (to be reported in data output)
+  libcodes <- as.integer(flibpaths)
+  libcodes[!is.na(libcodes)] <- sprintf("[%i]", libcodes[!is.na(libcodes)])
+
+  # add in packages in library
+  data <- data.frame(
+
+    Library    = renv_diagnostics_packages_version(libstate, all),
+    Source     = renv_diagnostics_packages_sources(libstate, all),
+    Lockfile   = renv_diagnostics_packages_version(lockfile, all),
+    Source     = renv_diagnostics_packages_sources(lockfile, all),
+    Path       = libcodes,
+    Dependency = deps,
+
+    stringsAsFactors = FALSE,
+    check.names      = FALSE
+
+  )
+
+  # print it out
+  renv_scope_options(width = 9000)
+  print(data)
+
+  # print library codes
+  fmt <- "[%s]: %s"
+  vwritef()
+  vwritef(fmt, format(seq_along(levels(flibpaths))), format(levels(flibpaths)))
+
+}
+
+renv_diagnostics_packages_version <- function(lockfile, all) {
+
+  data <- rep.int(NA_character_, length(all))
+  names(data) <- all
+
+  formatted <- map_chr(lockfile$Packages, `[[`, "Version")
+  data[names(formatted)] <- formatted
+
+  data
+
+}
+
+renv_diagnostics_packages_sources <- function(lockfile, all) {
+
+  data <- rep.int(NA_character_, length(all))
+  names(data) <- all
+
+  sources <- map_chr(lockfile$Packages, function(record) {
+    record$Repository %||% record$Source %||% "<unknown>"
+  })
+
+  data[names(sources)] <- sources
+  data
+
+}
+
+renv_diagnostics_packages_lockfile <- function(project) {
 
   lockpath <- file.path(project, "renv.lock")
   if (!file.exists(lockpath)) {
     vwritef("This project has not yet been snapshotted: 'renv.lock' does not exist.")
-    return()
+    return(list())
   }
 
-  lockfile <- renv_lockfile_read(lockpath)
-  records <- renv_records(lockfile)
-  vwritef("There are %i package(s) recorded in the lockfile.", length(records))
-  renv_pretty_print_records(records)
+  renv_lockfile_read(lockpath)
 
 }
 
-renv_diagnostics_library <- function(project) {
-
-  vwritef(header("Library"))
+renv_diagnostics_packages_library <- function(project) {
 
   library <- renv_paths_library(project = project)
   if (!file.exists(library)) {
     fmt <- "The project library %s does not exist."
-    return(vwritef(fmt, renv_path_pretty(library)))
+    vwritef(fmt, renv_path_pretty(library))
   }
 
-  lockfile <- snapshot(project = project,
-                       library = library,
-                       lockfile = NULL,
-                       type = "all")
-
-  records <- renv_records(lockfile)
-  vwritef("The are %i package(s) installed in the project library.", length(records))
-  vwritef("Library path: %s", renv_path_pretty(library))
+  snapshot(project = project, lockfile = NULL, type = "all")
 
 }
 
-renv_diagnostics_dependencies <- function(project) {
+renv_diagnostics_packages_dependencies <- function(project) {
 
-  vwritef(header("Dependencies"))
-
-  deps <- dependencies(project,
-                       progress = FALSE,
-                       errors = "reported",
-                       dev = TRUE)
-
-  if (empty(deps))
-    return(vwritef("[no usages of R packages discovered in this project]"))
-
-  renv_scope_options(width = 200)
-  print(deps)
+  dependencies(project,
+               progress = FALSE,
+               errors = "reported",
+               dev = TRUE)
 
 }
 
