@@ -46,7 +46,8 @@
 #'   `.Rprofile` to load the project.
 #'
 #' - `renv/.gitignore`: This is used to instruct Git to ignore the project's
-#'   private library, as it does not need to be
+#'   private library, as it should normally not be committed to a version
+#'   control repository.
 #'
 #' - `.Rbuildignore`: to ensure that the `renv` directory is ignored during
 #'   package development; e.g. when attempting to build or install a package
@@ -83,14 +84,18 @@ init <- function(project = NULL,
 {
   renv_consent_check()
   renv_scope_error_handler()
-  renv_dots_disallow(...)
+  renv_dots_check(...)
+
+  project <- project %||% getwd()
 
   # prepare and move into project directory
-  project <- project %||% getwd()
   renv_init_validate_project(project, force)
   renv_init_settings(project, settings)
   setwd(project)
 
+  # collect dependencies
+  renv_dependencies_scope(project, action = "init")
+
   # be quiet in RStudio projects (as we will normally restart automatically)
   quiet <- !is.null(getOption("restart"))
 
@@ -107,8 +112,8 @@ init <- function(project = NULL,
 
   # determine appropriate action
   action <- renv_init_action(project, library, lockfile)
-  if (empty(action)) {
-    message("Operation aborted.")
+  if (empty(action) || identical(action, "cancel")) {
+    message("* Operation aborted.")
     return(invisible(FALSE))
   }
 
@@ -116,13 +121,13 @@ init <- function(project = NULL,
   if (action == "init") {
     vwritef("* Initializing project ...")
     renv_libpaths_activate(project = project)
-    renv_bootstrap_impl(project)
+    renv_imbue_impl(project)
     hydrate(project = project, library = library)
-    snapshot(project = project, library = library, confirm = FALSE)
+    snapshot(project = project, library = library, prompt = FALSE)
   } else if (action == "restore") {
     vwritef("* Restoring project ... ")
     ensure_directory(library)
-    restore(project = project, confirm = FALSE)
+    restore(project = project, library = library, prompt = FALSE)
   }
 
   # activate the newly-hydrated project
@@ -134,40 +139,74 @@ init <- function(project = NULL,
 
 renv_init_action <- function(project, library, lockfile) {
 
-  has_library  <- file.exists(library)
-  has_lockfile <- file.exists(lockfile)
-
   # figure out appropriate action
-  action <- case(
+  case(
 
-    has_lockfile && has_library  ~ "ask",
-    has_lockfile && !has_library ~ "restore",
+    # if both the library and lockfile exist, ask user for intended action
+    file.exists(lockfile) && file.exists(library)
+      ~ renv_init_action_conflict_lockfile(project, library, lockfile),
 
-    !has_lockfile && has_library  ~ "ask",
-    !has_lockfile && !has_library ~ "init"
+    # if a private library exists but no lockfile, ask whether we should use it
+    !file.exists(lockfile) && file.exists(library)
+      ~ renv_init_action_conflict_library(project, library, lockfile),
+
+    # if a lockfile exists but not a library, we just want to restore
+    file.exists(lockfile) && !file.exists(library)
+      ~ "restore",
+
+    # otherwise, we juse want to initialize the project
+    ~ "init"
 
   )
 
-  # ask the user for an action to take when required
-  if (interactive() && action == "ask") {
+}
 
-    title <- "This project already has a lockfile. What would you like to do?"
-    choices <- c(
-      restore = "Restore the project from the lockfile.",
-      init    = "Discard the lockfile and re-initialize the project.",
-      nothing = "Activate the project without snapshotting or installing any packages."
-    )
+renv_init_action_conflict_lockfile <- function(project, library, lockfile) {
 
-    selection <- tryCatch(
-      utils::select.list(choices, title = title, graphics = FALSE),
-      interrupt = function(e) ""
-    )
+  if (!interactive())
+    return("nothing")
 
-    action <- names(selection)
+  title <- "This project already has a lockfile. What would you like to do?"
+  choices <- c(
+    restore = "Restore the project from the lockfile.",
+    init    = "Discard the lockfile and re-initialize the project.",
+    nothing = "Activate the project without snapshotting or installing any packages.",
+    cancel  = "Abort project initialization."
+  )
 
-  }
+  selection <- tryCatch(
+    utils::select.list(choices, title = title, graphics = FALSE),
+    interrupt = identity
+  )
 
-  action
+  if (inherits(selection, "interrupt"))
+    return(NULL)
+
+  names(selection)
+
+}
+
+renv_init_action_conflict_library <- function(project, library, lockfile) {
+
+  if (!interactive())
+    return("nothing")
+
+  title <- "This project already has a private library. What would you like to do?"
+  choices <- c(
+    nothing = "Activate the project and use the existing library.",
+    init    = "Re-initialize the project with a new library.",
+    cancel  = "Abort project initialization."
+  )
+
+  selection <- tryCatch(
+    utils::select.list(choices, title = title, graphics = FALSE),
+    interrupt = identity
+  )
+
+  if (inherits(selection, "interrupt"))
+    return(NULL)
+
+  names(selection)
 
 }
 
