@@ -24,7 +24,7 @@
 run <- function(script, ..., job = NULL, name = NULL, project = NULL) {
 
   renv_scope_error_handler()
-  renv_dots_disallow(...)
+  renv_dots_check(...)
 
   script <- renv_path_normalize(script, winslash = "/", mustWork = TRUE)
 
