@@ -1,8 +1,4 @@
 
-renv_sandbox_enabled <- function(project) {
-  renv_config("sandbox.enabled", default = TRUE)
-}
-
 renv_sandbox_activate <- function(project = NULL) {
 
   # attempt the activation
@@ -22,23 +18,10 @@ renv_sandbox_activate_impl <- function(project) {
   syslibs <- c(renv_libpaths_site(), renv_libpaths_system())
   syslibs <- renv_path_normalize(syslibs, winslash = "/", mustWork = FALSE)
 
-  # create a temporary library
+  # generate the sandbox
   sandbox <- file.path(tempdir(), "renv-system-library")
   ensure_directory(sandbox)
-
-  # find system packages in the system library
-  syspkgs <- renv_installed_packages(
-    lib.loc = renv_libpaths_system(),
-    priority = c("base", "recommended")
-  )
-
-  # link into temporary library
-  sources <- with(syspkgs, file.path(LibPath, Package))
-  targets <- with(syspkgs, file.path(sandbox, Package))
-  names(targets) <- sources
-  enumerate(targets, function(source, target) {
-    renv_file_link(source, target)
-  })
+  renv_sandbox_generate(sandbox)
 
   # override .Library, .Library.site
   base <- .BaseNamespaceEnv
@@ -53,6 +36,10 @@ renv_sandbox_activate_impl <- function(project) {
   # to update the library paths
   renv_sandbox_activate_check(newlibs)
 
+  # add a callback that double-checks the sandbox is active
+  # and working as intended
+  addTaskCallback(renv_sandbox_task)
+
   # return new library paths
   renv_libpaths_all()
 
@@ -93,6 +80,27 @@ renv_sandbox_activate_check <- function(libs) {
 
 }
 
+renv_sandbox_generate <- function(sandbox) {
+
+  # find system packages in the system library
+  syspkgs <- renv_installed_packages(
+    lib.loc = renv_libpaths_system(),
+    priority = c("base", "recommended")
+  )
+
+  # link into temporary library
+  sources <- with(syspkgs, file.path(LibPath, Package))
+  targets <- with(syspkgs, file.path(sandbox, Package))
+  names(targets) <- sources
+  enumerate(targets, function(source, target) {
+    renv_file_link(source, target)
+  })
+
+  # return sandbox path
+  sandbox
+
+}
+
 renv_sandbox_deactivate <- function() {
 
   # get library paths sans .Library, .Library.site
@@ -111,3 +119,19 @@ renv_sandbox_deactivate <- function() {
   renv_libpaths_all()
 
 }
+
+renv_sandbox_task <- function(...) {
+
+  enabled <- config$sandbox.enabled()
+  if (!enabled)
+    return(FALSE)
+
+  sandbox <- tail(.libPaths(), n = 1L)
+  if (!file.exists(sandbox)) {
+    warning("the renv sandbox was deleted; it will be re-generated", call. = FALSE)
+    renv_sandbox_generate(sandbox)
+  }
+
+  TRUE
+
+}
