@@ -6,7 +6,7 @@ test_that("we can query actions for a sample project", {
   renv_tests_scope("bread")
   renv_scope_options(renv.config.auto.snapshot = FALSE)
 
-  renv::init(settings = list(snapshot.type = "simple"))
+  renv::init(settings = list(snapshot.type = "all"))
   renv::install("breakfast")
 
   acts <- actions("snapshot", library = renv_paths_library(), project = getwd())
